* [GIT PULL] writeback data corruption fix
@ 2014-01-13 11:37 Fengguang Wu
0 siblings, 0 replies; only message in thread
From: Fengguang Wu @ 2014-01-13 11:37 UTC (permalink / raw)
To: Linus Torvalds; +Cc: Jan Kara, linux-fsdevel, LKML
Linus,
Please pull a writeback fix, it has been in linux-next for one month.
The following changes since commit 374b105797c3d4f29c685f3be535c35f5689b30e:
Linux 3.13-rc3 (2013-12-06 09:34:04 -0800)
are available in the git repository at:
git://git.kernel.org/pub/scm/linux/kernel/git/wfg/linux.git tags/writeback-fixes
for you to fetch changes up to f9b0e058cbd04ada76b13afffa7e1df830543c24:
writeback: Fix data corruption on NFS (2013-12-14 04:21:26 +0800)
----------------------------------------------------------------
fix data corruption on NFS writeback
----------------------------------------------------------------
Jan Kara (1):
writeback: Fix data corruption on NFS
fs/fs-writeback.c | 15 +++++++++------
1 file changed, 9 insertions(+), 6 deletions(-)
diff --git a/fs/fs-writeback.c b/fs/fs-writeback.c
index 1f4a10e..e0259a1 100644
--- a/fs/fs-writeback.c
+++ b/fs/fs-writeback.c
@@ -516,13 +516,16 @@ writeback_single_inode(struct inode *inode, struct bdi_writeback *wb,
}
WARN_ON(inode->i_state & I_SYNC);
/*
* Skip inode if it is clean. We don't want to mess with writeback
* lists in this function since flusher thread may be doing for example
* sync in parallel and if we move the inode, it could get skipped. So
* here we make sure inode is on some writeback list and leave it there
* unless we have completely cleaned the inode.
*/
- if (!(inode->i_state & I_DIRTY))
+ if (!(inode->i_state & I_DIRTY) &&
+ (wbc->sync_mode != WB_SYNC_ALL ||
+ !mapping_tagged(inode->i_mapping, PAGECACHE_TAG_WRITEBACK)))
goto out;
inode->i_state |= I_SYNC;
spin_unlock(&inode->i_lock);
^ permalink raw reply related [flat|nested] only message in thread
only message in thread, other threads:[~2014-01-13 11:37 UTC | newest]
Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2014-01-13 11:37 [GIT PULL] writeback data corruption fix Fengguang Wu
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
@@ -516,13 +516,16 @@ writeback_single_inode(struct inode *inode, struct bdi_writeback *wb,
WARN_ON(inode->i_state & I_SYNC);
/*
- * Skip inode if it is clean. We don't want to mess with writeback
- * lists in this function since flusher thread may be doing for example
- * sync in parallel and if we move the inode, it could get skipped. So
- * here we make sure inode is on some writeback list and leave it there
- * unless we have completely cleaned the inode.
+ * Skip inode if it is clean and we have no outstanding writeback in
+ * WB_SYNC_ALL mode. We don't want to mess with writeback lists in this
+ * function since flusher thread may be doing for example sync in
+ * parallel and if we move the inode, it could get skipped. So here we
+ * make sure inode is on some writeback list and leave it there unless
+ * we have completely cleaned the inode.
*/
all data and code used by this external index.